@@ -1,3 +1,5 @@
+import os
+import warnings
 from copy import deepcopy
 from typing import Any, Dict, List, Optional
 
@@ -31,10 +33,19 @@ class Resources(object):
         Initial global scan for a system.
         '''
         resources = {'cpu': psutil.Process().cpu_affinity()}
-        gpus = GPUtil.getAvailable(
-            limit=100, maxLoad=gpu_load, maxMemory=gpu_memory)
-        if len(gpus) > 0:
-            resources['gpu'] = gpus
+        try:
+            gpus = GPUtil.getAvailable(
+                limit=100, maxLoad=gpu_load, maxMemory=gpu_memory)
+            visible_gpus = os.environ.get('CUDA_VISIBLE_DEVICES')
+            if visible_gpus is not None:
+                gpus = [*map(int, visible_gpus.split(','))]
+            # Remove env for correct GPU indices in subprocesses
+            del os.environ['CUDA_VISIBLE_DEVICES']
+            if len(gpus) > 0:
+                resources['gpu'] = gpus
+        except Exception as e:
+            warnings.warn(
+                f'GPU resources unavailable due to scan failure: {repr(e)}', RuntimeWarning)
         return resources
 
     def split(self, num_split: int):
